@@ -1,10 +1,12 @@
+from __future__ import annotations
+
 from procrastinate import cli
 
 
 def main(name):
     # The curse of 100% coverage
     if name == "__main__":
-        cli.cli()
+        cli.main()
 
 
 main(__name__)
