@@ -1,4 +1,4 @@
-from typing import Optional
+from __future__ import annotations
 
 from procrastinate import blueprints, job_context
 
@@ -10,8 +10,10 @@ async def remove_old_jobs(
     context: job_context.JobContext,
     *,
     max_hours: int,
-    queue: Optional[str] = None,
-    remove_error: Optional[bool] = False,
+    queue: str | None = None,
+    remove_failed: bool | None = False,
+    remove_cancelled: bool | None = False,
+    remove_aborted: bool | None = False,
 ) -> None:
     """
     This task cleans your database by removing old jobs. Note that jobs and linked
@@ -24,11 +26,20 @@ async def remove_old_jobs(
     queue :
         The name of the queue in which jobs will be deleted. If not specified, the
         task will delete jobs from all queues.
-    remove_error :
+    remove_failed:
         By default only successful jobs will be removed. When this parameter is True
         failed jobs will also be deleted.
+    remove_cancelled:
+        By default only successful jobs will be removed. When this parameter is True
+        cancelled jobs will also be deleted.
+    remove_aborted:
+        By default only successful jobs will be removed. When this parameter is True
+        aborted jobs will also be deleted.
     """
-    assert context.app
     await context.app.job_manager.delete_old_jobs(
-        nb_hours=max_hours, queue=queue, include_error=remove_error
+        nb_hours=max_hours,
+        queue=queue,
+        include_failed=remove_failed,
+        include_cancelled=remove_cancelled,
+        include_aborted=remove_aborted,
     )
