@@ -1,4 +1,6 @@
-import datetime
+from __future__ import annotations
+
+from procrastinate.retry import RetryDecision
 
 
 class ProcrastinateException(Exception):
@@ -32,12 +34,6 @@ class TaskAlreadyRegistered(ProcrastinateException):
     """
 
 
-class JobError(ProcrastinateException):
-    """
-    Job ended with an exception.
-    """
-
-
 class LoadFromPathError(ImportError, ProcrastinateException):
     """
     App was not found at the provided path, or the loaded object is not an App.
@@ -49,11 +45,17 @@ class JobRetry(ProcrastinateException):
     Job should be retried.
     """
 
-    def __init__(self, scheduled_at: datetime.datetime):
-        self.scheduled_at = scheduled_at
+    def __init__(self, retry_decision: RetryDecision):
+        self.retry_decision = retry_decision
         super().__init__()
 
 
+class JobAborted(ProcrastinateException):
+    """
+    Job was aborted.
+    """
+
+
 class AppNotOpen(ProcrastinateException):
     """
     App was not open. Procrastinate App needs to be opened using:
@@ -85,9 +87,16 @@ class UniqueViolation(ConnectorException):
     ``exception.constraint_name``.
     """
 
-    def __init__(self, *args, constraint_name: str):
+    def __init__(self, *args, constraint_name: str | None, queueing_lock: str | None):
         super().__init__(*args)
         self.constraint_name = constraint_name
+        self.queueing_lock = queueing_lock
+
+
+class NoResult(ConnectorException):
+    """
+    No result was returned by the database query.
+    """
 
 
 class MissingApp(ProcrastinateException):
@@ -99,8 +108,8 @@ class MissingApp(ProcrastinateException):
 
 class SyncConnectorConfigurationError(ProcrastinateException):
     """
-    A synchronous connector (probably Psycopg2Connector) was used, but the operation
-    needs an asynchronous connector (AiopgConnector). Please check your App
+    A synchronous connector was used, but the operation
+    needs an asynchronous connector. Please check your App
     configuration.
     """
 
@@ -113,3 +122,18 @@ class CallerModuleUnknown(ProcrastinateException):
 
 class RunTaskError(ProcrastinateException):
     """One of the specified coroutines ended with an exception"""
+
+
+class InvalidTimestamp(ProcrastinateException):
+    """
+    Periodic task launched with a timestamp kwarg not matching the
+    defer_timestamp arg
+    """
+
+
+class FunctionPathError(ProcrastinateException):
+    """Couldn't automatically generate a unique name for a function"""
+
+
+class MovedElsewhere(ProcrastinateException):
+    """The object has been moved elsewhere"""
