@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 import asyncio
+import contextlib
 import logging
+import os
 import signal
 import threading
-from contextlib import contextmanager
-from typing import Any, Callable, Optional
+from typing import Any, Callable
 
 logger = logging.getLogger(__name__)
 
@@ -21,8 +24,15 @@ logger = logging.getLogger(__name__)
 # one. And hope that there was no previously set async handler.
 
 
-@contextmanager
+@contextlib.contextmanager
 def on_stop(callback: Callable[[], None]):
+    if os.name == "nt":
+        logger.warning(
+            "Skipping signal handling, does not work on Windows",
+            extra={"action": "skip_signal_handlers"},
+        )
+        yield
+        return
     if threading.current_thread() is not threading.main_thread():
         logger.warning(
             "Skipping signal handling, because this is not the main thread",
@@ -35,7 +45,7 @@ def on_stop(callback: Callable[[], None]):
     sigterm_handler = signal.getsignal(signal.SIGTERM)
 
     uninstalled = False
-    loop: Optional[asyncio.AbstractEventLoop]
+    loop: asyncio.AbstractEventLoop | None
     try:
         loop = asyncio.get_running_loop()
     except RuntimeError:
@@ -61,7 +71,7 @@ def on_stop(callback: Callable[[], None]):
             )
 
 
-def install(loop: Optional[asyncio.AbstractEventLoop], handler: Callable):
+def install(loop: asyncio.AbstractEventLoop | None, handler: Callable):
     logger.debug(
         "Installing signal handler", extra={"action": "install_signal_handlers"}
     )
@@ -74,7 +84,7 @@ def install(loop: Optional[asyncio.AbstractEventLoop], handler: Callable):
 
 
 def uninstall(
-    loop: Optional[asyncio.AbstractEventLoop],
+    loop: asyncio.AbstractEventLoop | None,
     sigint_handler: Any,
     sigterm_handler: Any,
 ):
